[![tests](https://github.com/e11bio/volara-torch/actions/workflows/tests.yaml/badge.svg)](https://github.com/e11bio/volara-torch/actions/workflows/tests.yaml)
[![ruff](https://github.com/e11bio/volara-torch/actions/workflows/ruff.yaml/badge.svg)](https://github.com/e11bio/volara-torch/actions/workflows/ruff.yaml)
[![mypy](https://github.com/e11bio/volara-torch/actions/workflows/mypy.yaml/badge.svg)](https://github.com/e11bio/volara-torch/actions/workflows/mypy.yaml)
<!-- [![codecov](https://codecov.io/gh/e11bio/volara-torch/branch/main/graph/badge.svg?token=YOUR_TOKEN)](https://codecov.io/gh/e11bio/volara-torch) -->

# volara-torch
A plugin for volara that includes pytorch models and a `Predict` task

# Available blockwise operations:
- `Predict`: Model Prediction
